package com.sun.java.swing.plaf.motif;

import javax.swing.border.Border;
import java.awt.Insets;
import java.awt.Dimension;
import javax.swing.plaf.UIResource;
import java.awt.Graphics;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.AbstractButton;
import sun.awt.AppContext;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Color;
import javax.swing.plaf.basic.BasicToggleButtonUI;

public class MotifToggleButtonUI extends BasicToggleButtonUI
{
    private static final Object MOTIF_TOGGLE_BUTTON_UI_KEY;
    protected Color selectColor;
    private boolean defaults_initialized;
    
    public MotifToggleButtonUI() {
        this.defaults_initialized = false;
    }
    
    public static ComponentUI createUI(JComponent component) {
        AppContext appContext = AppContext.getAppContext();
        MotifToggleButtonUI value = (MotifToggleButtonUI)appContext.get(MotifToggleButtonUI.MOTIF_TOGGLE_BUTTON_UI_KEY);
        if (value == null) {
            value = new MotifToggleButtonUI();
            appContext.put(MotifToggleButtonUI.MOTIF_TOGGLE_BUTTON_UI_KEY, value);
            return value;
        }
        return value;
    }
    
    public void installDefaults(AbstractButton abstractButton) {
        super.installDefaults(abstractButton);
        if (!this.defaults_initialized) {
            this.selectColor = UIManager.getColor(this.getPropertyPrefix() + "select");
            this.defaults_initialized = true;
        }
        LookAndFeel.installProperty(abstractButton, "opaque", Boolean.FALSE);
    }
    
    @Override
    protected void uninstallDefaults(AbstractButton b) {
        super.uninstallDefaults(b);
        this.defaults_initialized = false;
    }
    
    protected Color getSelectColor() {
        return this.selectColor;
    }
    
    @Override
    protected void paintButtonPressed(Graphics graphics, AbstractButton abstractButton) {
        if (abstractButton.isContentAreaFilled()) {
            Color color = graphics.getColor();
            Dimension size = abstractButton.getSize();
            Insets insets = abstractButton.getInsets();
            Insets margin = abstractButton.getMargin();
            if ((abstractButton.getBackground() instanceof UIResource)) {
                graphics.setColor(this.getSelectColor());
            }
            graphics.fillRect(insets.left - margin.left, insets.top - margin.top, size.width - (insets.left - margin.left) - (insets.right - margin.right), size.height - (insets.top - margin.top) - (insets.bottom - margin.bottom));
            graphics.setColor(color);
        }
    }
    
    public Insets getInsets(JComponent component) {
        Border border = component.getBorder();
        return (border != null) ? border.getBorderInsets(component) : new Insets(0, 0, 0, 0);
    }
    
    static {
        MOTIF_TOGGLE_BUTTON_UI_KEY = new Object();
    }
}
